package com.fastest.pass.welcome.presentation.ui.fragment

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.compose.ui.platform.ComposeView
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import com.fastest.pass.ui.theme.FastestPassTheme
import com.fastest.pass.welcome.presentation.ui.component.ClickType.LOGIN_CLICK
import com.fastest.pass.welcome.presentation.ui.component.ClickType.SIGNUP_CLICK
import com.fastest.pass.welcome.presentation.ui.component.WelcomeTutorial
import com.fastest.pass.welcome.presentation.viewmodel.WelcomeViewModel
import com.fastest.pass.welcome.utils.WelcomeNavigation
import com.fastest.pass.welcome.utils.WelcomeNavigationRoute
import dagger.hilt.android.AndroidEntryPoint
import javax.inject.Inject

@AndroidEntryPoint
class WelcomeFragment : Fragment() {

    val viewModel : WelcomeViewModel by viewModels()

    @Inject
    lateinit var navigation : WelcomeNavigation

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        navigation.navigateTo(this)
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        return ComposeView(requireActivity()).apply {
            setContent {
                FastestPassTheme {
                    WelcomeTutorial { clickType ->

                        when (clickType) {
                            LOGIN_CLICK -> {
                                viewModel.navigateTo(WelcomeNavigationRoute.OpenLogin)
                            }

                            SIGNUP_CLICK -> {
                                viewModel.navigateTo(WelcomeNavigationRoute.OpenSignup)
                            }
                        }
                    }
                }
            }
        }
    }
}